---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2002-2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
-- (#) ./base/db/Oracle8i/event/en_event_schema.sql BL_core_schema_8.0.5_8.0.5.5.07_20081024  124729
-- (#) 
--
CREATE SEQUENCE en_event_typegrp_seq;
CREATE SEQUENCE en_event_type_seq;
CREATE SEQUENCE en_event_seq;

-- SEAde28502

 CREATE TABLE en_event_type_group(
	group_id	INTEGER,
	group_name      VARCHAR2(64),
	group_label     VARCHAR2(64),
	 CONSTRAINT pk_en_event_type_group PRIMARY KEY(group_id)
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;


-- forward - allows the event to be placed into the queue for notification purposes
CREATE TABLE en_event_type (
    event_type_id    INTEGER,
    name	     VARCHAR2(32) NOT NULL,
    label            VARCHAR2(64) NOT NULL,
    view_name        VARCHAR2(30),
    msg_proc         VARCHAR2(64),
    can_schedule     CHAR(1) DEFAULT 'N',
      CONSTRAINT en_event_type_can_schedule_ck check (can_schedule in ('Y','N')),
    can_notify       CHAR(1) DEFAULT 'Y',
      CONSTRAINT en_event_type_can_notify_ck check (can_notify in ('Y','N')),
    group_id         INTEGER NOT NULL,
    forward          CHAR(1) DEFAULT 'Y' NOT NULL,
      CONSTRAINT en_event_type_forward_ck check(forward in ('Y', 'N')),
    CONSTRAINT pk_en_event_type PRIMARY KEY (event_type_id),
    --CONSTRAINT en_event_type_name_nn CHECK (name IS NOT NULL),
    CONSTRAINT en_event_type_name_unq UNIQUE (name) USING INDEX PCTFREE 0 TABLESPACE wm_flexpm,
    CONSTRAINT en_event_type_label_unq UNIQUE (label) USING INDEX PCTFREE 0 TABLESPACE wm_flexpm,
    CONSTRAINT fk_en_event_type_groupid 
		   FOREIGN KEY (group_id) REFERENCES en_event_type_group(group_id)
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;

CREATE TABLE en_event (
    event_id        INTEGER,
    event_time      DATE DEFAULT SYSDATE,
    event_type_id   INTEGER, 
    data_tstamp     DATE,
    handled_tstamp  DATE,
    is_read         CHAR(1) DEFAULT 'N',
    CONSTRAINT pk_en_event PRIMARY KEY (event_id),
    CONSTRAINT fk_en_event_event_type
               FOREIGN KEY (event_type_id) 
               REFERENCES en_event_type (event_type_id),
    CONSTRAINT chk_en_event_is_read CHECK (is_read IN ('Y', 'N')),
    CONSTRAINT en_event_event_time_nn CHECK (event_time IS NOT NULL),
    CONSTRAINT en_event_event_type_id_nn CHECK (event_type_id IS NOT NULL)
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 25;

-- SEAde39501: Remove constraint fk_task_status_event
--
--ALTER TABLE task_status ADD
--      (CONSTRAINT fk_task_status_event FOREIGN KEY (event_id) REFERENCES en_event(event_id));
--

-- Load Metadata
-- SEAde31430 name is Data Load for backward compatiblity.

CREATE INDEX en_event_is_read ON en_event (is_read)
TABLESPACE wm_flexpm
;

CREATE TABLE en_event_data_load (
    event_id        INTEGER,
    instance_id     INTEGER,
    entity_id       INTEGER,
    file_type_id     INTEGER, 
    CONSTRAINT pk_event_data_load PRIMARY KEY (event_id),
    CONSTRAINT fk_en_event_data_load 
               FOREIGN KEY (event_id)
               REFERENCES en_event (event_id) ON DELETE CASCADE,
    CONSTRAINT fk_en_event_data_load_file
               FOREIGN KEY (file_type_id)
               REFERENCES wm_file_control (file_type_id)
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;

CREATE OR REPLACE VIEW en_event_data_load_v AS
SELECT e.event_id,e.event_time,e.event_type_id,e.data_tstamp,e.handled_tstamp,
edl.instance_id, edl.entity_id, edl.file_type_id
FROM en_event e, en_event_data_load edl, en_event_type et
WHERE e.event_id = edl.event_id
AND e.event_type_id = et.event_type_id
AND et.name = 'Data load';


CREATE TABLE schedule_event ( 
    schedule_id     INTEGER,
    event_type_id   INTEGER,
    CONSTRAINT pk_schedule_event PRIMARY KEY (schedule_id),
    CONSTRAINT fk_schedule_event_sched_id
               FOREIGN KEY (schedule_id)
	       REFERENCES schedule (schedule_id) ON DELETE CASCADE,
    CONSTRAINT fk_schedule_event_type_id
               FOREIGN KEY (event_type_id)
               REFERENCES en_event_type (event_type_id),
    CONSTRAINT schedule_event_type_nn CHECK (event_type_id IS NOT NULL)	   
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;


CREATE GLOBAL TEMPORARY TABLE en_event_filter_tmp 
ON COMMIT DELETE ROWS
  AS SELECT event_id,event_time,event_type_id,data_tstamp,handled_tstamp
       FROM en_event WHERE 0 = 1;


ALTER TABLE en_event_filter_tmp ADD CONSTRAINT pk_en_event_filter_tmp PRIMARY KEY (event_id);


CREATE TABLE en_event_file_load(
    event_id           INTEGER,
    error_message      VARCHAR2(128),
    file_name          VARCHAR2(1024),
    log_file           VARCHAR2(1024), 
    instance_id        INTEGER,
    entity_id          INTEGER,
    file_type_id       INTEGER,
    NUMOFINTERVAL      INTEGER,
    CONSTRAINT pk_event_file_load PRIMARY KEY (event_id),
    CONSTRAINT fk_en_event_file_load 
               FOREIGN KEY (event_id)
               REFERENCES en_event (event_id) ON DELETE CASCADE,
    CONSTRAINT fk_en_event_file_load_file
               FOREIGN KEY (file_type_id)
               REFERENCES wm_file_control (file_type_id)
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;


CREATE OR REPLACE VIEW en_event_file_load_v AS
SELECT e.event_id,e.event_time,e.event_type_id,e.data_tstamp,e.handled_tstamp,
 efl.error_message,efl.file_name,efl.log_file,
  efl.INSTANCE_ID,efl.ENTITY_ID,efl.FILE_TYPE_ID,
  efl.NUMOFINTERVAL
FROM en_event e, en_event_file_load efl, en_event_type et
WHERE e.event_id    = efl.event_id
AND e.event_type_id = et.event_type_id
AND et.name in ('FILE_LOAD_S','FILE_LOAD_F');

CREATE TABLE en_event_file_missing(
    event_id           INTEGER,
    error_message      VARCHAR2(128),
    file_name          VARCHAR2(1024),
    log_file           VARCHAR2(1024), 
    instance_id        INTEGER,
    entity_id          INTEGER,
    file_type_id       INTEGER,
    NUMOFINTERVAL      INTEGER,
    CONSTRAINT pk_event_file_missing PRIMARY KEY (event_id),
    CONSTRAINT fk_en_event_file_missing 
               FOREIGN KEY (event_id)
               REFERENCES en_event (event_id) ON DELETE CASCADE,
    CONSTRAINT fk_en_event_file_missing_file
               FOREIGN KEY (file_type_id)
               REFERENCES wm_file_control (file_type_id)
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;


CREATE OR REPLACE VIEW en_event_file_missing_v AS
SELECT e.event_id,e.event_time,e.event_type_id,e.data_tstamp,e.handled_tstamp,
 efl.error_message,efl.file_name,efl.log_file,
  efl.INSTANCE_ID,efl.ENTITY_ID,efl.FILE_TYPE_ID,
  efl.NUMOFINTERVAL
FROM en_event e, en_event_file_missing efl, en_event_type et
WHERE e.event_id    = efl.event_id
AND e.event_type_id = et.event_type_id
AND et.name in ('FILE_MISSING');

CREATE TABLE en_event_sa_file_missing(
    event_id           INTEGER,
    sa_sched_id        INTEGER,
    filemissing_msg    VARCHAR2(4000),
    file_name          VARCHAR2(1024),
    log_file           VARCHAR2(1024),
    CONSTRAINT pk_en_sa_file_missing PRIMARY KEY (event_id),
    CONSTRAINT fk_en_sa_file_missing
               FOREIGN KEY (event_id)
               REFERENCES en_event (event_id) ON DELETE CASCADE
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;

CREATE OR REPLACE VIEW en_event_sa_file_missing_v AS
SELECT e.event_id, e.event_time, e.event_type_id, e.data_tstamp, e.handled_tstamp,
       esfm.sa_sched_id, 
       esfm.filemissing_msg, esfm.file_name, esfm.log_file
  FROM en_event e, en_event_sa_file_missing esfm, en_event_type et
 WHERE e.event_id      = esfm.event_id
   AND e.event_type_id = et.event_type_id
   AND et.name in ('SA_FILE_MISSING');

CREATE TABLE pm_notification_event_map( 
    notify_id       INTEGER,
    event_type_id   INTEGER,
    CONSTRAINT pk_notif_eventmap PRIMARY KEY (notify_id,event_type_id),
    CONSTRAINT fk_notif_eventmap_notify_id
               FOREIGN KEY (notify_id) REFERENCES pm_notification (id) ON DELETE CASCADE,
    CONSTRAINT fk_notif_eventmap_eventtype_id
               FOREIGN KEY (event_type_id) REFERENCES en_event_type (event_type_id)
)
ORGANIZATION INDEX
TABLESPACE wm_flexpm
PCTFREE 0;


CREATE OR REPLACE FUNCTION get_eventype_id(pname IN VARCHAR2)
RETURN INTEGER IS

v_evnttype_id INTEGER;

BEGIN

  select event_type_id into v_evnttype_id
  from en_event_type
  where  name = pname;

  return v_evnttype_id;

EXCEPTION WHEN NO_DATA_FOUND THEN

  return null;

END;
/
SHOW ERRORS

-- This table is not an IOT due to the length of its record.
-- This is always accessed through the view and will always
-- have an event_id for the key.
CREATE TABLE en_event_status_change(event_id           INTEGER,
			            status_message     VARCHAR2(4000),
				    summary            VARCHAR2(256),
			            long_message       VARCHAR2(4000),
				    log_file           VARCHAR2(255),
				    start_time         DATE,
				    end_time           DATE,
    CONSTRAINT pk_event_status_change PRIMARY KEY (event_id),
    CONSTRAINT fk_en_event_status_change FOREIGN KEY (event_id) 
     REFERENCES en_event (event_id) ON DELETE CASCADE
)
TABLESPACE wm_flexpm
PCTFREE 0;


CREATE OR REPLACE VIEW en_event_status_change_v AS
SELECT e.event_id,e.event_time,e.event_type_id,e.data_tstamp,e.handled_tstamp,
  esc.status_message,esc.summary,esc.long_message,
         esc.start_time,esc.end_time,esc.log_file
FROM en_event e, en_event_status_change esc, en_event_type et
 WHERE e.event_id    = esc.event_id
   AND e.event_type_id = et.event_type_id
   AND et.name in ('SCHED_REPORT_GROUP_S','SCHED_REPORT_GROUP_F','BUSYHOUR_S','BUSYHOUR_F',
   'SUMMATION_S','SUMMATION_F','PARTMAINT_D_S','PARTMAINT_D_F',
   'PARTMAINT_W_S','PARTMAINT_W_F', 'PARTMAINT_M_S','PARTMAINT_M_F',
   'ANALYZE_S','ANALYZE_F','RGFP_S','RGFP_F',
   'SCENARIO_AD_S','SCENARIO_AD_F','SOFTALARM_S','SOFTALARM_F',
   'SUMMARY_CLEAN_S','SUMMARY_CLEAN_F','AUTOCLEAN_S','AUTOCLEAN_F',
   'BUSYHOUR_CLEAN_S','BUSYHOUR_CLEAN_F','EVENT_CLEAN_S','EVENT_CLEAN_F',
   'EXPECTATION_S','EXPECTATION_F',
   'SOFTALARM_S', 'SOFTALARM_F',
   'AGGREGATOR_S', 'AGGREGATOR_F',
   'SUMMARY_CLEAN_S', 'SUMMARY_CLEAN_F',
   'AUTOCLEAN_S', 'AUTOCLEAN_F',
   'BUSYHOUR_CLEAN_S', 'BUSYHOUR_CLEAN_F',
   'EVENT_CLEAN_S', 'EVENT_CLEAN_F',
   'EXPECTATION_S', 'EXPECTATION_F',
   'SAEXT_PUSH_S', 'SAEXT_PUSH_F');


-- integrate is_read column to en_event table creation SQL
-- SEAde30164 Read events from d/b

--ALTER TABLE en_event ADD IS_READ CHAR(1) DEFAULT 'N'
--check(IS_READ in ('Y','N'));

CREATE GLOBAL TEMPORARY TABLE en_event_unprocessed(event_id      NUMBER,
                                                   event_type_id NUMBER,
                                                   data_tstamp   DATE,
                                                   is_scheduled char(1) DEFAULT 'N' ,
                                                   is_notify    char(1) DEFAULT 'N')
ON COMMIT DELETE ROWS;


exit;
