---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05,5724-T06
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------
--
set timing on;
set serveroutput on size 1000000;
set lines 200;

DECLARE
   doNotRemove INTEGER := 1;
BEGIN
   BEGIN
      -- Back out saext if 8.0.5.0 thru 8.0.5.4 are only revisions left
      SELECT count(*)
        INTO doNotRemove
        FROM component_version v
       WHERE v.revision LIKE '8.0.5.%'
         AND v.revision NOT LIKE '8.0.5.0'
         AND v.revision NOT LIKE '8.0.5.1'
         AND v.revision NOT LIKE '8.0.5.2'
         AND v.revision NOT LIKE '8.0.5.3'
         AND v.revision NOT LIKE '8.0.5.4'
         AND v.component_id =
             (SELECT component_id
                FROM component c
               WHERE UPPER(c.component_type) = 'CORE')
         AND v.component_version_id !=
             (SELECT MAX(component_version_id)
                FROM component_version v2
               WHERE v2.component_id =
                     (SELECT component_id
                        FROM component c
                       WHERE UPPER(c.component_type) = 'CORE')
                 AND v2.revision LIKE '8.0.5.%');

    EXCEPTION WHEN NO_DATA_FOUND THEN
       doNotRemove := 0;

    END;

   IF doNotRemove != 0 THEN
      dbms_output.put_line('SAEXT tables up to date');
      RETURN;
   END IF;

   dbms_output.put_line('Downgrading SAEXT tables');

   wm_queue_admin.drop_queue('saext_q', 'saext_qt');
   run_sql('drop package body saext_aq');
   run_sql('drop package saext_aq');
   run_sql('drop sequence saext_seq');
   run_sql('drop table saext_log cascade constraints');
   run_sql('drop package body saext_queue_admin');
   run_sql('drop package saext_queue_admin');
   run_sql('drop table saext_kpi_tab cascade constraints');
   run_sql('drop table saext_exclude');
   run_sql('drop index saext_alarm_idx');
   run_sql('drop table saext_alarm cascade constraints');
   run_sql('drop package body saext_pm');
   run_sql('drop package saext_pm');
   run_sql('drop package body saext');
   run_sql('drop package saext');
   run_sql('drop type saext_message');

   BEGIN 
      DELETE FROM sa_time_range WHERE id = 6;
      COMMIT;
      
      -- Only remove column if data can be deleted
      run_sql('ALTER TABLE sa_time_range DROP CONSTRAINT saext_tr_class_chk');
      run_sql('ALTER TABLE sa_time_range DROP COLUMN CLASS');
      
   EXCEPTION WHEN others THEN
      NULL;
   END;

   BEGIN
      DELETE FROM sa_aggregator WHERE id IN (4,5);
      COMMIT;
      
      -- Only remove column if data can be deleted
      run_sql('ALTER TABLE sa_aggregator DROP CONSTRAINT saext_ag_class_chk');
      run_sql('ALTER TABLE sa_aggregator DROP COLUMN CLASS');

   EXCEPTION WHEN others THEN
      NULL;
   END;

   DELETE FROM part_tables WHERE table_name='SAEXT_KPI_TAB';
   COMMIT;
   
   DELETE FROM subclass_table WHERE name = 'extSoftAlarm';
   COMMIT;

   wm_sysval.deletesysval('SAEXT_SOFTALARM');
   wm_sysval.deletesysval('SAEXT_AGGREGATOR');
   wm_sysval.deletesysval('SAEXT_DEQUEUE_TIMEOUT');
   wm_sysval.deletesysval('SAEXT_ENRICH');
   wm_sysval.deletesysval('SAEXT_ENRICH_DAYS');
   wm_sysval.deletesysval('SAEXT_LINK');
   wm_sysval.deletesysval('SAEXT_MIN_STORAGE');
   wm_sysval.deletesysval('SAEXT_ORIGIN');
   wm_sysval.deletesysval('SAEXT_PROCEDURE');
   wm_sysval.deletesysval('SAEXT_SEVERITY');
   wm_sysval.deletesysval('SAEXT_STDDEV');
   wm_sysval.deletesysval('SAEXT_STORE_LE_ZERO');
   wm_sysval.deletesysval('SAEXT_TAG_HARDFAIL');
   wm_sysval.deletesysval('SAEXT_TAG_NETWORKDOMAIN');
   wm_sysval.deletesysval('SAEXT_TECH');
   wm_sysval.deletesysval('SAEXT_VENDOR');
   COMMIT;
   
END;
/
